package com.qmth.ops.api.security;

import com.qmth.boot.core.exception.UnauthorizedException;
import com.qmth.boot.core.security.model.AccessEntity;
import com.qmth.ops.api.dto.LoginResult;
import com.qmth.ops.biz.domain.Env;
import com.qmth.ops.biz.domain.Role;
import com.qmth.ops.biz.domain.User;

public class AdminSession implements AccessEntity {

    private User user;

    public AdminSession(User user) {
        this.user = user;
    }

    public LoginResult getLoginResult(String fileServer) {
        LoginResult result = new LoginResult();
        result.setId(user.getId());
        result.setName(user.getName());
        result.setRole(user.getRole());
        result.setSession(getIdentity());
        result.setToken(getSecret());
        result.setFileServer(fileServer);
        return result;
    }

    public User getUser() {
        return user;
    }

    public void validateRole(Role... roles) {
        if (!user.hasRole(roles)) {
            throw new UnauthorizedException("没有操作权限");
        }
    }

    public void validateEnv(Env env) {
        if (!user.hasRole(Role.ADMIN) && !user.getId().equals(env.getUserId())) {
            throw new UnauthorizedException("没有环境操作权限");
        }
    }

    @Override
    public String getIdentity() {
        return user.getId().toString();
    }

    @Override
    public String getSecret() {
        return user.getAccessToken();
    }
}
